@@ -1,5 +1,6 @@
 /********************************************************************
 Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+Copyright 2018  David Edmundson <davidedmundson@kde.org>
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -49,11 +50,13 @@ struct org_kde_kwin_blur_manager;
 struct org_kde_kwin_contrast_manager;
 struct org_kde_kwin_slide_manager;
 struct org_kde_plasma_shell;
+struct org_kde_plasma_virtual_desktop_management;
 struct org_kde_plasma_window_management;
 struct org_kde_kwin_server_decoration_manager;
 struct org_kde_kwin_server_decoration_palette_manager;
 struct xdg_shell;
 struct zxdg_shell_v6;
+struct xdg_wm_base;
 struct zwp_relative_pointer_manager_v1;
 struct zwp_pointer_gestures_v1;
 struct zwp_pointer_constraints_v1;
@@ -61,6 +64,7 @@ struct zxdg_exporter_v2;
 struct zxdg_importer_v2;
 struct zwp_idle_inhibit_manager_v1;
 struct zxdg_output_manager_v1;
+struct zxdg_decoration_manager_v1;
 
 namespace KWayland
 {
@@ -82,6 +86,7 @@ class IdleInhibitManager;
 class RemoteAccessManager;
 class Output;
 class PlasmaShell;
+class PlasmaVirtualDesktopManagement;
 class PlasmaWindowManagement;
 class PointerConstraints;
 class PointerGestures;
@@ -105,6 +110,7 @@ class XdgImporterUnstableV2;
 class XdgExporter;
 class XdgImporter;
 class XdgOutputManager;
+class XdgDecorationManager;
 
 /**
  * @short Wrapper for the wl_registry interface.
@@ -175,7 +181,10 @@ public:
         AppMenu, ///Refers to org_kde_kwin_appmenu @since 5.42
         ServerSideDecorationPalette, ///Refers to org_kde_kwin_server_decoration_palette_manager @since 5.42
         RemoteAccessManager, ///< Refers to org_kde_kwin_remote_access_manager interface, @since 5.45
+        PlasmaVirtualDesktopManagement, ///< Refers to org_kde_plasma_virtual_desktop_management interface @since 5.52
         XdgOutputUnstableV1, ///refers to zxdg_output_v1, @since 5.47
+        XdgShellStable, ///refers to xdg_wm_base @since 5.48
+        XdgDecorationUnstableV1, ///refers to zxdg_decoration_manager_v1, @since 5.54
     };
     explicit Registry(QObject *parent = nullptr);
     virtual ~Registry();
@@ -224,7 +233,7 @@ public:
      *
      * The EventQueue should be set before the Registry gets setup.
      * The EventQueue gets automatically added to all interfaces created by
-     * this Registry. So that all objects are in teh same EventQueue.
+     * this Registry. So that all objects are in the same EventQueue.
      *
      * @param queue The event queue to use for this Registry.
      **/
@@ -390,6 +399,16 @@ public:
      * @since 5.4
      **/
     org_kde_plasma_shell *bindPlasmaShell(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the org_kde_plasma_virtual_desktop_management with @p name and @p version.
+     * If the @p name does not exist or is not for the Plasma Virtual desktop interface,
+     * @c null will be returned.
+     *
+     * Prefer using createPlasmaShell instead.
+     * @see createPlasmaShell
+     * @since 5.52
+     **/
+    org_kde_plasma_virtual_desktop_management *bindPlasmaVirtualDesktopManagement(uint32_t name, uint32_t version) const;
     /**
      * Binds the org_kde_plasma_window_management with @p name and @p version.
      * If the @p name does not exist or is not for the Plasma window management interface,
@@ -397,7 +416,7 @@ public:
      *
      * Prefer using createPlasmaWindowManagement instead.
      * @see createPlasmaWindowManagement
-     * @since 5.4
+     * @since 5.46
      **/
     org_kde_plasma_window_management *bindPlasmaWindowManagement(uint32_t name, uint32_t version) const;
     /**
@@ -530,6 +549,16 @@ public:
      * @since 5.39
      **/
     zxdg_shell_v6 *bindXdgShellUnstableV6(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the zxdg_shell_v6 (unstable version 6) with @p name and @p version.
+     * If the @p name does not exist or is not for the xdg shell interface in unstable version 5,
+     * @c null will be returned.
+     *
+     * Prefer using createXdgShell instead.
+     * @see createXdgShell
+     * @since 5.39
+     **/
+    xdg_wm_base *bindXdgShellStable(uint32_t name, uint32_t version) const;
     /**
      * Binds the zwp_relative_pointer_manager_v1 with @p name and @p version.
      * If the @p name does not exist or is not for the relative pointer interface in unstable version 1,
@@ -626,6 +655,17 @@ public:
      **/
     zxdg_output_manager_v1 *bindXdgOutputUnstableV1(uint32_t name, uint32_t version) const;
 
+    /**
+     * Binds the zxdg_decoration_manager_v1 with @p name and @p version.
+     * If the @p name does not exist,
+     * @c null will be returned.
+     *
+     * Prefer using createXdgDecorationManager instead.
+     * @see createXdgDecorationManager
+     * @since 5.54
+     **/
+    zxdg_decoration_manager_v1 *bindXdgDecorationUnstableV1(uint32_t name, uint32_t version) const;
+
     ///@}
 
     /**
@@ -801,6 +841,22 @@ public:
      * @since 5.4
      **/
     PlasmaShell *createPlasmaShell(quint32 name, quint32 version, QObject *parent = nullptr);
+    /**
+     * Creates a PlasmaVirtualDesktopManagement and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * Note: in case @p name is invalid or isn't for the org_kde_plasma_virtual_desktop_management interface,
+     * the returned VirtualDesktop will not be valid. Therefore it's recommended to call
+     * isValid on the created instance.
+     *
+     * @param name The name of the org_kde_plasma_virtual_desktop_management interface to bind
+     * @param version The version or the org_kde_plasma_virtual_desktop_management interface to use
+     * @param parent The parent for PlasmaShell
+     *
+     * @returns The created PlasmaShell.
+     * @since 5.52
+     **/
+    PlasmaVirtualDesktopManagement *createPlasmaVirtualDesktopManagement(quint32 name, quint32 version, QObject *parent = nullptr);
     /**
      * Creates a PlasmaWindowManagement and sets it up to manage the interface identified by
      * @p name and @p version.
@@ -1149,6 +1205,23 @@ public:
      **/
     XdgOutputManager *createXdgOutputManager(quint32 name, quint32 version, QObject *parent = nullptr);
 
+    /**
+     * Creates an XdgDecorationManager and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * Note: in case @p name is invalid or isn't for the zxdg_decoration_manager_v1 interface,
+     * the returned XdgDecorationManager will not be valid. Therefore it's recommended to call
+     * isValid on the created instance.
+     *
+     * @param name The name of the zxdg_decoration_manager_v1 interface to bind
+     * @param version The version or the zxdg_decoration_manager_v1 interface to use
+     * @param parent The parent for XdgDecorationManager
+     *
+     * @returns The created XdgDecorationManager.
+     * @since 5.54
+     **/
+    XdgDecorationManager *createXdgDecorationManager(quint32 name, quint32 version, QObject *parent = nullptr);
+
     ///@}
 
 
@@ -1234,6 +1307,13 @@ Q_SIGNALS:
      * @since 5.4
      **/
     void plasmaShellAnnounced(quint32 name, quint32 version);
+    /**
+     * Emitted whenever a org_kde_plasma_virtual_desktop_management interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.52
+     **/
+    void plasmaVirtualDesktopManagementAnnounced(quint32 name, quint32 version);
     /**
      * Emitted whenever a org_kde_plasma_window_management interface gets announced.
      * @param name The name for the announced interface
@@ -1403,6 +1483,22 @@ Q_SIGNALS:
      */
     void xdgOutputAnnounced(quint32 name, quint32 version);
 
+    /**
+     * Emitted whenever a xdg_wm_base (stable xdg shell) interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.48
+     **/
+    void xdgShellStableAnnounced(quint32 name, quint32 version);
+
+    /**
+     * Emitted whenever a zxdg_decoration_manager_v1 interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.54
+     **/
+    void xdgDecorationAnnounced(quint32 name, quint32 version);
+
     ///@}
 
     /**
@@ -1467,6 +1563,12 @@ Q_SIGNALS:
      * @since 5.4
      **/
     void plasmaShellRemoved(quint32 name);
+    /**
+     * Emitted whenever a org_kde_plasma_virtual_desktop_management interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.52
+     **/
+    void plasmaVirtualDesktopManagementRemoved(quint32 name);
     /**
      * Emitted whenever a org_kde_plasma_window_management interface gets removed.
      * @param name The name for the removed interface
@@ -1611,6 +1713,19 @@ Q_SIGNALS:
      * @since 5.47
      **/
     void xdgOutputRemoved(quint32 name);
+    /**
+     * Emitted whenever an xdg_wm_base (stable xdgshell) interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.48
+     **/
+    void xdgShellStableRemoved(quint32 name);
+
+    /**
+     * Emitted whenever a zxdg_decoration_manager_v1 gets removed.
+     * @param name The name of the removed interface
+     * @since 5.54
+     **/
+    void xdgDecorationRemoved(quint32 name);
 
     ///@}
     /**
